/*
 * @(#)HNode.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy;

import java.awt.LayoutManager;
import chrriis.uihierarchy.compatibility.List;
import chrriis.uihierarchy.layout.HLayoutManager;

/**
 * A sub node in the hierarchy.
 * @version 2.0 2003.11.02
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class HNode extends HParentLevel {

  /**
   * Construct a node.
   * @param uihConfig The configuration.
   * @param parent The hierarchy parent component of this one.
   * @param container The container.
   */
  protected HNode(UIHConfig uihConfig, HParentLevel parent, Object container) {
    super(uihConfig, parent, container);
  }

  /**
   * Use the specified layout manager.
   * @param hLayoutManager The layout manager to use.
   * @return The hierarchy node.
   */
  public HNode layout(HLayoutManager hLayoutManager) {
    layout_(hLayoutManager);
    return this;
  }
  
  /**
   * Use the specified layout manager.
   * @param layoutManager The layout manager to use.
   * @return The hierarchy node.
   */
  public HNode layout(LayoutManager layoutManager) {
    layout_(layoutManager);
    return this;
  }

  /**
   * Use the specified constraints.
   * @param constraints The constraints to use.
   * @return The hierarchy node.
   */
  public HNode constrain(Object constraints) {
    constrain_(constraints);
    return this;
  }

  /**
   * Set the sub constraints.
   * @param subConstraints The sub constraints.
   * @return The hierarchy node.
   */
  public HNode subConstrain(Object subConstraints) {
    subConstrain_(subConstraints);
    return this;
  }

  /**
   * Map the given name to the current component. The mapping definitions are
   * kept in the <code>UIHConfig</code> configuration.
   * @param name The name of the component.
   * @return The hierarchy node.
   * @see chrriis.uihierarchy.UIHConfig
   */
  public HNode map(String name) {
    map_(name);
    return this;
  }

  /**
   * Add the level to the debugging process, using default parameters.
   */
  public HNode debug() {
    debug(null);
    return this;
  }

  /**
   * Add the level to the debugging process.
   * @param parameters The parameters to use to debug, which can actually be a
   * debugger to use.
   */
  public HNode debug(Object parameters) {
    debug_(parameters);
    return this;
  }

  /**
   * Get a String representation of the hierarchy level.
   * @see java.lang.Object#toString()
   */
  public String toString() {
    String layoutManagerName = null;
    boolean isLayoutManagerDefined = isLayoutManagerDefined();
    if(isLayoutManagerDefined) {
      if(getLayoutManager() == null) {
        layoutManagerName = "null";
      } else {
        layoutManagerName = getClassName(getLayoutManager().getClass());
      }
    }
    String mapList = "";
    List keyList = getConfig().getMapList(this);
    if(!keyList.isEmpty()) {
      mapList = " [Map:";
      for(int i=0; i<keyList.size(); i++) {
        mapList += (i==0?" ":", ") + keyList.get(i);
      }
      mapList += "]";
    }
    return "+ "
    + getClassName(getComponent().getClass())
    + (isLayoutManagerDefined? " [Layout: " + layoutManagerName + "]": "")
    + (getConstraints() != null? " [Cons: " + getConstraints() + "]": "")
    + (getSubConstraints() != null? " [SubCons: " + getSubConstraints() + "]": "")
    + mapList
    ;
  }

}
