/*
 * @(#)CardHLayout.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.layout;

import java.awt.CardLayout;
import java.awt.LayoutManager;

import chrriis.uihierarchy.UIHConfig;
import chrriis.uihierarchy.util.UnitParser;

/**
 * A card layout that is lazily created, using the UIH configuration. This
 * allows the use of units to determine the gaps, which are defined as
 * <code>String</code>s.
 * @version 1.0 2005.02.06
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class CardHLayout implements HLayoutManager {

  protected String hgap;
  protected String vgap;

  /**
   * Creates a new card layout with gaps of size zero.
   */
  public CardHLayout() {
    this(null, null);
  }

  /**
   * Creates a new card layout with the specified horizontal and vertical gaps.
   * @param hgap
   * @param vgap
   */             
  public CardHLayout(String hgap, String vgap) {
    this.hgap = hgap;
    this.vgap = vgap;
  }

  public LayoutManager createLayout(UIHConfig uihConfig) {
    int hgap = 0;
    if(this.hgap != null) {
      hgap = UnitParser.intPixelValue(uihConfig, this.hgap);
    }
    int vgap = 0;
    if(this.vgap != null) {
      vgap = UnitParser.intPixelValue(uihConfig, this.vgap);
    }
    return new CardLayout(hgap, vgap);
  }

}
