/*
 * @(#)GridHLayout.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.layout;

import java.awt.GridLayout;
import java.awt.LayoutManager;

import chrriis.uihierarchy.UIHConfig;
import chrriis.uihierarchy.util.UnitParser;

/**
 * A grid layout that is lazily created, using the UIH configuration. This
 * allows the use of units to determine the gaps, which are defined as
 * <code>String</code>s.
 * @version 1.0 2005.02.06
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class GridHLayout implements HLayoutManager {

  protected int rows;
  protected int cols;
  protected String hgap;
  protected String vgap;

  /**
   * Creates a grid layout with a default of one column per component, in a single row.
   */
  public GridHLayout() {
    this(1, 0);
  }
            
  /**
   * Creates a grid layout with the specified number of rows and columns.
   * @param rows
   * @param cols
   */
  public GridHLayout(int rows, int cols) {
    this(rows, cols, null, null);
  }

  /**
   * Creates a grid layout with the specified number of rows and columns.
   * @param rows
   * @param cols
   * @param hgap
   * @param vgap
   */
  public GridHLayout(int rows, int cols, String hgap, String vgap) { 
    this.rows = rows;
    this.cols = cols;
    this.hgap = hgap;
    this.vgap = vgap;
  }

  public LayoutManager createLayout(UIHConfig uihConfig) {
    int hgap = 0;
    if(this.hgap != null) {
      hgap = UnitParser.intPixelValue(uihConfig, this.hgap);
    }
    int vgap = 0;
    if(this.vgap != null) {
      vgap = UnitParser.intPixelValue(uihConfig, this.vgap);
    }
    return new GridLayout(rows, cols, hgap, vgap);
  }

}
