/*
 * @(#)ArrayComponentResolver.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.xml.resolver;

import java.awt.Component;
import chrriis.uihierarchy.compatibility.HashMap;
import chrriis.uihierarchy.compatibility.Map;

/**
 * The component resolver for arrays.
 * @version 1.0 2003.10.06
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class ArrayComponentResolver implements ComponentResolver {

  /** The map of components. */
  protected Map componentsMap;

  /**
   * Construct a component resolver for an array.
   * @param components The array of components. They are in the form
   * {"name_of_component_1", component_1,
   *  "name_of_component_2", component_2, ...}
   * <br>or:<br>
   * {component_1, component_2, ...} with the components' names set.
   * <br>or a mix of both.
   */
  public ArrayComponentResolver(Object[] components) {
    Map componentsMap = null;
    if(components != null && components.length != 0) {
      componentsMap = new HashMap(components.length / 2);
      for(int i=0; i<components.length; i++) {
        if(components[i] instanceof String) {
          componentsMap.put(components[i], components[i+1]);
          i++;
        } else {
          componentsMap.put(((Component)components[i]).getName(), components[i]);
        }
      }
    }
    this.componentsMap = componentsMap;
  }

  /**
   * Resolve a component from its name.
   * @param name The name of the component to resolve.
   * @see chrriis.uihierarchy.xml.resolver.ComponentResolver#resolve(java.lang.String)
   */
  public Object resolve(String name) {
    if(componentsMap == null) {
      return null;
    }
    return componentsMap.get(name);
  }

}
